@@ -1,6 +1,5 @@
 /* 
  *
- * $Id: k3bmixedprojectinterface.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -21,27 +20,35 @@
 
 #include <dcopref.h>
 
-class K3bMixedDoc;
-class K3bDataProjectInterface;
-class K3bAudioProjectInterface;
+namespace K3b {
+    class MixedDoc;
+}
+namespace K3b {
+    class DataProjectInterface;
+}
+namespace K3b {
+    class AudioProjectInterface;
+}
 
 
-class K3bMixedProjectInterface : public K3bProjectInterface
+namespace K3b {
+class MixedProjectInterface : public ProjectInterface
 {
   K_DCOP
 
  public:
-  K3bMixedProjectInterface( K3bMixedDoc*, const char* name = 0 );
+  MixedProjectInterface( MixedDoc* );
 
  k_dcop:
   DCOPRef dataPart() const;
   DCOPRef audioPart() const;
 
  private:
-  K3bMixedDoc* m_mixedDoc;
+  MixedDoc* m_mixedDoc;
 
-  K3bDataProjectInterface* m_dataInterface;
-  K3bAudioProjectInterface* m_audioInterface;
+  DataProjectInterface* m_dataInterface;
+  AudioProjectInterface* m_audioInterface;
 };
+}
 
 #endif
